==> com.liferay.dynamic.data.mapping.form.builder-3.0.37.jar: META-INF/resources/js/components/FormBuilder/withClickableFields.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-builder@3.0.37/js/components/FormBuilder/withClickableFields.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-dom', 'frontend-js-metal-web$metal-events', 'frontend-js-metal-web$metal-jsx', './props.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _metalDom = _interopRequireDefault(require("frontend-js-metal-web$metal-dom"));

  var _metalEvents = require("frontend-js-metal-web$metal-events");

  var _metalJsx = _interopRequireDefault(require("frontend-js-metal-web$metal-jsx"));

  var _props = _interopRequireDefault(require("./props.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(Object(source), true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(Object(source)).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var withClickableFields = function withClickableFields(ChildComponent) {
    var ClickableFields =
    /*#__PURE__*/
    function (_Component) {
      _inherits(ClickableFields, _Component);

      function ClickableFields() {
        _classCallCheck(this, ClickableFields);

        return _possibleConstructorReturn(this, _getPrototypeOf(ClickableFields).apply(this, arguments));
      }

      _createClass(ClickableFields, [{
        key: "attached",
        value: function attached() {
          this._eventHandler = new _metalEvents.EventHandler();

          this._eventHandler.add(this.delegate('click', '.ddm-field-container', this._handleFieldClicked.bind(this)));
        }
      }, {
        key: "disposed",
        value: function disposed() {
          this._eventHandler.removeAllListeners();
        }
      }, {
        key: "render",
        value: function render() {
          IncrementalDOM.elementOpenStart(ChildComponent);
          iDOMHelpers.forOwn(this.props, iDOMHelpers.attr);
          IncrementalDOM.elementOpenEnd(ChildComponent);
          return IncrementalDOM.elementClose(ChildComponent);
        }
      }, {
        key: "_handleFieldClicked",
        value: function _handleFieldClicked(event) {
          var delegateTarget = event.delegateTarget;
          var dispatch = this.context.dispatch;
          var fieldName = delegateTarget.dataset.fieldName;
          var activePage = this.context.store.state.activePage;
          event.stopPropagation();

          if (!event.delegateTarget.children[1].hasAttribute('aria-grabbed')) {
            activePage = parseInt(_metalDom["default"].closest(event.delegateTarget, '[data-ddm-page]').dataset.ddmPage, 10);
          }

          dispatch('fieldClicked', {
            activePage: activePage,
            fieldName: fieldName
          });
        }
      }]);

      return ClickableFields;
    }(_metalJsx["default"]);

    ClickableFields.PROPS = _objectSpread({}, _props["default"]);
    return ClickableFields;
  };

  var _default = withClickableFields;
  exports["default"] = _default;
  //# sourceMappingURL=withClickableFields.es.js.map
});
//# sourceMappingURL=withClickableFields.es.js.map

==> com.liferay.dynamic.data.mapping.form.builder-3.0.40.jar: META-INF/resources/js/components/FormBuilder/withClickableFields.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-builder@3.0.40/js/components/FormBuilder/withClickableFields.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-dom', 'frontend-js-metal-web$metal-events', 'frontend-js-metal-web$metal-jsx', './props.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _metalDom = _interopRequireDefault(require("frontend-js-metal-web$metal-dom"));

  var _metalEvents = require("frontend-js-metal-web$metal-events");

  var _metalJsx = _interopRequireDefault(require("frontend-js-metal-web$metal-jsx"));

  var _props = _interopRequireDefault(require("./props.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(Object(source), true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(Object(source)).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var withClickableFields = function withClickableFields(ChildComponent) {
    var ClickableFields = /*#__PURE__*/function (_Component) {
      _inherits(ClickableFields, _Component);

      function ClickableFields() {
        _classCallCheck(this, ClickableFields);

        return _possibleConstructorReturn(this, _getPrototypeOf(ClickableFields).apply(this, arguments));
      }

      _createClass(ClickableFields, [{
        key: "attached",
        value: function attached() {
          this._eventHandler = new _metalEvents.EventHandler();

          this._eventHandler.add(this.delegate('click', '.ddm-field-container', this._handleFieldClicked.bind(this)));
        }
      }, {
        key: "disposed",
        value: function disposed() {
          this._eventHandler.removeAllListeners();
        }
      }, {
        key: "render",
        value: function render() {
          IncrementalDOM.elementOpenStart(ChildComponent);
          iDOMHelpers.forOwn(this.props, iDOMHelpers.attr);
          IncrementalDOM.elementOpenEnd(ChildComponent);
          return IncrementalDOM.elementClose(ChildComponent);
        }
      }, {
        key: "_handleFieldClicked",
        value: function _handleFieldClicked(event) {
          var delegateTarget = event.delegateTarget;
          var dispatch = this.context.dispatch;
          var fieldName = delegateTarget.dataset.fieldName;
          var activePage = this.context.store.state.activePage;
          event.stopPropagation();

          if (!event.delegateTarget.children[1].hasAttribute('aria-grabbed')) {
            activePage = parseInt(_metalDom["default"].closest(event.delegateTarget, '[data-ddm-page]').dataset.ddmPage, 10);
          }

          dispatch('fieldClicked', {
            activePage: activePage,
            fieldName: fieldName
          });
        }
      }]);

      return ClickableFields;
    }(_metalJsx["default"]);

    ClickableFields.PROPS = _objectSpread({}, _props["default"]);
    return ClickableFields;
  };

  var _default = withClickableFields;
  exports["default"] = _default;
  //# sourceMappingURL=withClickableFields.es.js.map
});
//# sourceMappingURL=withClickableFields.es.js.map
